# Changelog

- This file provides a full account of all changes to `dbt-bigquery`
- The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html),
and is generated by [Changie](https://github.com/miniscruff/changie)
- Changes are listed under the (pre-)release in which they first appear
- Subsequent releases include changes from previous releases
- "Breaking changes" listed under a version may require action from end users or external maintainers when upgrading to that version
- Do not edit this file directly. This file is auto-generated using [changie](https://github.com/miniscruff/changie)
- For details on how to document a change, see the [contributing guide](/CONTRIBUTING.md#changelog-entry)

## dbt-bigquery 1.11.0-rc1 - November 19, 2025

### Features

- Add support for python UDFs ([#1410](https://github.com/dbt-labs/dbt-adapters/issues/1410))
- Add support for aggregate sql functions ([#1432](https://github.com/dbt-labs/dbt-adapters/issues/1432))

### Dependencies

- Bump minimum dbt-adapters to 1.19.0 ([#1421](https://github.com/dbt-labs/dbt-adapters/pull/1421))



## dbt-bigquery 1.11.0-b2 - November 04, 2025

### Fixes

- Fix BigFrames python model + oauth + notebook template by adding a Request to creds.refresh calll ([#1379](https://github.com/dbt-labs/dbt-adapters/issues/1379))

### Under the Hood

- Update bigquery job handling to invoke job.cancel on timeout ([#1355](https://github.com/dbt-labs/dbt-adapters/issues/1355))
- Test that bigquery does nothing with volatility ([#1345](https://github.com/dbt-labs/dbt-adapters/issues/1345))
- Test handling of unknown function macro lookup ([#1344](https://github.com/dbt-labs/dbt-adapters/issues/1344))

### Dependencies

- Drop support for python 3.9 ([#1412](https://github.com/dbt-labs/dbt-adapters/pull/1412))

## dbt-bigquery 1.11.0-b1 - October 07, 2025

### Features

- Add support for BigQuery resource tags via `resource_tags` configuration option ([#565](https://github.com/dbt-labs/dbt-adapters/issues/565), [#577](https://github.com/dbt-labs/dbt-adapters/issues/577))
- Support the updating of incremental model description after initial creation ([#585](https://github.com/dbt-labs/dbt-adapters/issues/585))
- Add `enable_change_history` option for models on BigQuery. ([#1206](https://github.com/dbt-labs/dbt-adapters/issues/1206))
- Add support for scalar functions ([#1290](https://github.com/dbt-labs/dbt-adapters/issues/1290))

### Fixes

- BigFrames notebook execution when using a service account with oauth ([#1231](https://github.com/dbt-labs/dbt-adapters/issues/1231))
- Ensure we have exchanged a refresh-token for a token prior to detemining notebook user in BigFrames ([#1219](https://github.com/dbt-labs/dbt-adapters/issues/1219))
- Fix references to function properties in function macros ([#1365](https://github.com/dbt-labs/dbt-adapters/issues/1365))

### Under the Hood

- Validate notebooks authorization request has succeeded ([#1307](https://github.com/dbt-labs/dbt-adapters/issues/1307))
- Emit SQLQueryStatus during query execution ([#1327](https://github.com/dbt-labs/dbt-adapters/issues/1327))

### Contributors
- [@Robin_CHESNE](https://github.com/Robin_CHESNE) ([#1206](https://github.com/dbt-labs/dbt-adapters/issues/1206))
- [@jspenmar](https://github.com/jspenmar) ([#1231](https://github.com/dbt-labs/dbt-adapters/issues/1231))
- [@kiwamizamurai](https://github.com/kiwamizamurai) ([#585](https://github.com/dbt-labs/dbt-adapters/issues/585))
- [@tnk-ysk](https://github.com/tnk-ysk) ([#565](https://github.com/dbt-labs/dbt-adapters/issues/565), [#577](https://github.com/dbt-labs/dbt-adapters/issues/577))

## dbt-bigquery 1.10.1 - July 29, 2025

### Features

- Support impersonate service account in bigframes mode ([#1202](https://github.com/dbt-labs/dbt-adapters/issues/1202))

### Fixes

- Add support for copy_partitions when used with static partitions. ([#540](https://github.com/dbt-labs/dbt-adapters/issues/540))
- Track notebook job status to avoid LRO in bigframes mode ([#1175](https://github.com/dbt-labs/dbt-adapters/issues/1175))

### Contributors
- [@Kayrnt](https://github.com/Kayrnt) ([#540](https://github.com/dbt-labs/dbt-adapters/issues/540))
- [@jialuoo](https://github.com/jialuoo) ([#1202](https://github.com/dbt-labs/dbt-adapters/issues/1202), [#1175](https://github.com/dbt-labs/dbt-adapters/issues/1175))

## dbt-bigquery 1.10.0-rc2 - June 24, 2025

### Features

- Add user agent in bigframes mode ([#1152](https://github.com/dbt-labs/dbt-adapters/issues/1152))

### Fixes

- Add create_notebook_client ([#977](https://github.com/dbt-labs/dbt-adapters/issues/977))
- Use execute wrapper instead of raw execute to add the query comment as query header ([#1090](https://github.com/dbt-labs/dbt-adapters/issues/1090))

### Under the Hood

- Issue drop statement before cloning ([#1077](https://github.com/dbt-labs/dbt-adapters/issues/1077))

### Dependencies

- update the lower bound for dbt-adapters version in dbt-bigquery to >=1.16 ([#1148](https://github.com/dbt-labs/dbt-adapters/pull/1148))
- add lower bound for google-auth in dbt-bigquery ([#1149](https://github.com/dbt-labs/dbt-adapters/pull/1149))

### Contributors
- [@Kayrnt](https://github.com/Kayrnt) ([#1090](https://github.com/dbt-labs/dbt-adapters/issues/1090))
- [@jeremyyeo](https://github.com/jeremyyeo) ([#1077](https://github.com/dbt-labs/dbt-adapters/issues/1077))
- [@jialuoo](https://github.com/jialuoo) ([#1152](https://github.com/dbt-labs/dbt-adapters/issues/1152), [#977](https://github.com/dbt-labs/dbt-adapters/issues/977))

## dbt-bigquery 1.10.0-rc1 - June 04, 2025

### Breaking Changes

- rename 'catalog' model config value to 'catalog_name' ([#1134](https://github.com/dbt-labs/dbt-adapters/issues/1134))

### Features

- Make Bigquery `api_endpoint` config option available for dbt client ([#https://github.com/dbt-labs/dbt-bigquery/pull/1017](https://github.com/dbt-labs/dbt-adapters/issues/https://github.com/dbt-labs/dbt-bigquery/pull/1017))
- Add support for managed Iceberg catalogs ([#1105](https://github.com/dbt-labs/dbt-adapters/issues/1105))
- generate storage_uri from external_volume, base_location_root and base_location_subpath ([#1129](https://github.com/dbt-labs/dbt-adapters/issues/1129))

### Fixes

- Set partial ordering mode as default in dbt bigframes ([#1035](https://github.com/dbt-labs/dbt-adapters/issues/1035))
- Set 1 hour as default timeout in bigframes mode ([#1070](https://github.com/dbt-labs/dbt-adapters/issues/1070))
- Set job_retry to None to resolve Google Cloud warning ([##1088](https://github.com/dbt-labs/dbt-adapters/issues/#1088))

### Under the Hood

- populate file_format from top level integration config field ([#1129](https://github.com/dbt-labs/dbt-adapters/issues/1129))
- Rename and separate out info schema and biglake catalog integrations ([#1129](https://github.com/dbt-labs/dbt-adapters/issues/1129))

### Dependencies

- bump dbt-core requirement to 1.10.0rc0 ([#1142](https://github.com/dbt-labs/dbt-adapters/pull/1142))

### Contributors
- [@OTooleMichael](https://github.com/OTooleMichael) ([#https://github.com/dbt-labs/dbt-bigquery/pull/1017](https://github.com/dbt-labs/dbt-adapters/issues/https://github.com/dbt-labs/dbt-bigquery/pull/1017))
- [@jialuoo](https://github.com/jialuoo) ([#1035](https://github.com/dbt-labs/dbt-adapters/issues/1035), [#1070](https://github.com/dbt-labs/dbt-adapters/issues/1070))
- [@katieclaiborne-duet](https://github.com/katieclaiborne-duet) ([##1088](https://github.com/dbt-labs/dbt-adapters/issues/#1088))

## dbt-bigquery 1.10.0-b1 - April 28, 2025

### Features

- Allow copy_partitions in microbatch ([#1414](https://github.com/dbt-labs/dbt-adapters/issues/1414))
- Add authentication method for Workload Identity Federation. ([#593](https://github.com/dbt-labs/dbt-adapters/issues/593))
- Add support for creating BigQuery labels from meta configuration ([#889](https://github.com/dbt-labs/dbt-adapters/issues/889))
- Support bigframes in dbt bigquery python model ([#921](https://github.com/dbt-labs/dbt-adapters/issues/921))
- Support timeout in bigframes mode of dbt python model ([#949](https://github.com/dbt-labs/dbt-adapters/issues/949))
- Support custom packages in bigframes mode ([#978](https://github.com/dbt-labs/dbt-adapters/issues/978))
- Support oauth secrets credential method in bigframes mode ([#1026](https://github.com/dbt-labs/dbt-adapters/issues/1026))

### Fixes

- Fix issue where dbt-bigquery was not retrying in certain retryable scenarios, e.g. 503's ([#682](https://github.com/dbt-labs/dbt-adapters/issues/682))
- Cast `event_time` to a timestamp prior to comparing against microbatch start/end time ([#1422](https://github.com/dbt-labs/dbt-adapters/issues/1422))
- Fix issue where rate limit errors on table service calls are not retried ([#1423](https://github.com/dbt-labs/dbt-adapters/issues/1423))
- Fix retry scenarios so that dbt always retries when BigQuery recommends a retry ([#263](https://github.com/dbt-labs/dbt-adapters/issues/263))
- Fix silently ignoring materialized view authorization ([#1471](https://github.com/dbt-labs/dbt-adapters/issues/1471))
- Format the outputs of notebook execution ([#943](https://github.com/dbt-labs/dbt-adapters/issues/943))
- Create a new default runtime template ([#950](https://github.com/dbt-labs/dbt-adapters/issues/950))
- use compute_region instead of dataproc_region ([#957](https://github.com/dbt-labs/dbt-adapters/issues/957))
- Fix the credential method issue ([#970](https://github.com/dbt-labs/dbt-adapters/issues/970))
- Raise an error when notebook execution failed ([#976](https://github.com/dbt-labs/dbt-adapters/issues/976))
- `datetime.datetime.utcnow()` is deprecated as of Python 3.12 ([#980](https://github.com/dbt-labs/dbt-adapters/issues/980))
- Make location optional in bigframes ([#1001](https://github.com/dbt-labs/dbt-adapters/issues/1001))
- Quick fix of session in table.sql ([#1003](https://github.com/dbt-labs/dbt-adapters/issues/1003))
- set job_timeout_ms in job config so BQ cancels queries on timeout ([#1004](https://github.com/dbt-labs/dbt-adapters/issues/1004))

### Under the Hood

- Move from setup.py to pyproject.toml and to hatch as a dev tool ([#1407](https://github.com/dbt-labs/dbt-adapters/issues/1407))
- replace DbtRuntime exception with DbtDatabase exception in dbt-bigquery connection exception handling ([#798](https://github.com/dbt-labs/dbt-adapters/issues/798))
- Added annotation for recording. ([#761](https://github.com/dbt-labs/dbt-adapters/issues/761))

### Dependencies

- Permits newer versions of google-cloud-storage than 2.4.x to be used, defaults to latest ([#931](https://github.com/dbt-labs/dbt-adapters/pull/931))

### Contributors
- [@borjavb](https://github.com/borjavb) ([#1414](https://github.com/dbt-labs/dbt-adapters/issues/1414))
- [@brabster](https://github.com/brabster) ([#931](https://github.com/dbt-labs/dbt-adapters/pull/931))
- [@jenniferjsmmiller](https://github.com/jenniferjsmmiller) ([#593](https://github.com/dbt-labs/dbt-adapters/issues/593))
- [@jialuoo](https://github.com/jialuoo) ([#921](https://github.com/dbt-labs/dbt-adapters/issues/921), [#949](https://github.com/dbt-labs/dbt-adapters/issues/949), [#978](https://github.com/dbt-labs/dbt-adapters/issues/978), [#1026](https://github.com/dbt-labs/dbt-adapters/issues/1026), [#943](https://github.com/dbt-labs/dbt-adapters/issues/943), [#950](https://github.com/dbt-labs/dbt-adapters/issues/950), [#957](https://github.com/dbt-labs/dbt-adapters/issues/957), [#970](https://github.com/dbt-labs/dbt-adapters/issues/970), [#976](https://github.com/dbt-labs/dbt-adapters/issues/976), [#1001](https://github.com/dbt-labs/dbt-adapters/issues/1001), [#1003](https://github.com/dbt-labs/dbt-adapters/issues/1003))
- [@kubikb](https://github.com/kubikb) ([#1471](https://github.com/dbt-labs/dbt-adapters/issues/1471))
- [@physcat](https://github.com/physcat) ([#889](https://github.com/dbt-labs/dbt-adapters/issues/889))

## Previous Releases
For information on prior major and minor releases, see their changelogs:
- [1.9](https://github.com/dbt-labs/dbt-bigquery/blob/1.9.latest/CHANGELOG.md)
- [1.8](https://github.com/dbt-labs/dbt-bigquery/blob/1.8.latest/CHANGELOG.md)
- [1.7](https://github.com/dbt-labs/dbt-bigquery/blob/1.7.latest/CHANGELOG.md)
- [1.6](https://github.com/dbt-labs/dbt-bigquery/blob/1.6.latest/CHANGELOG.md)
- [1.5](https://github.com/dbt-labs/dbt-bigquery/blob/1.5.latest/CHANGELOG.md)
- [1.4](https://github.com/dbt-labs/dbt-bigquery/blob/1.4.latest/CHANGELOG.md)
- [1.3](https://github.com/dbt-labs/dbt-bigquery/blob/1.3.latest/CHANGELOG.md)
- [1.2](https://github.com/dbt-labs/dbt-bigquery/blob/1.2.latest/CHANGELOG.md)
- [1.1](https://github.com/dbt-labs/dbt-bigquery/blob/1.1.latest/CHANGELOG.md)
- [1.0](https://github.com/dbt-labs/dbt-bigquery/blob/1.0.latest/CHANGELOG.md)
